Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| ATACADAO S.A.
CNPJ: 75.315.333/0121-15 Inscrição Estadual: 1090362886
ROD RST 287, 5500, CAMOBI, SANTA MARIA, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 111844 Série: 511 Data de Emissão: 08/03/2019 18:05:19
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 0375 3153 3301 2115 6551 1000 1118 4410 4857 9176
Protocolo de Autorização: 143190323628572
CONSUMIDOR
CPF: 044.272.479-97
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
14201952 | LEITE L.VIDA MOLICO | 6 | UN | 3,2 | 19,20
46102913 | FILE PEITO LAR IQF | 1 | UN | 10,4 | 10,40
61003900 | GRAO BICO GRANO | 1 | UN | 8,99 | 8,99
4921422 | MANDIOCA PACOTE | 1 | UN | 5,6 | 5,60
56535907 | FILE COXA E S/COXA P | 1 | UN | 16,7 | 16,70
44230936 | MASSA PIZZA ITALIANY | 3 | UN | 2,99 | 8,97
1788974 | KIWI | 1,512 | KG | 11,9 | 17,99
32150906 | PAO FORMA S.BOYS | 1 | UN | 4,29 | 4,29
49494133 | PAO INTEGRAL NUTRELL | 1 | UN | 9,8 | 9,80
59113962 | RF.QUEIJO PRATO FAT. | 1 | UN | 13,69 | 13,69
1646951 | BANANA PRATA | 0,852 | KG | 4,5 | 3,83
1643973 | BANANA NANICA | 0,586 | KG | 3,4 | 1,99
42009957 | P.HIG.PERSONAL VIP K | 1 | UN | 29,9 | 29,90
49570912 | AGUA M.DA PEDRA | 4 | UN | 5,09 | 20,36
31988953 | AGUA M.FONTE DA ILHA | 4 | UN | 3,89 | 15,56
3372971 | ARROZ CAMIL INTEGRAL | 1 | UN | 3,99 | 3,99
12474982 | ARROZ CAMIL AG.T1 | 1 | UN | 2,18 | 2,18
62248998 | ATUM ROBINSON | 4 | UN | 5,1 | 20,40
1078181 | ABACAXI | 2 | UN | 3,95 | 7,90
1075102 | MELANCIA GD | 1 | UN | 5,99 | 5,99
51583990 | SAC INST.BIO 60X70 | 3 | UN | 0,2 | 0,60
49301930 | SAB.FRANCIS CLASSICO | 2 | UN | 1,6 | 3,20
49303949 | SAB.FRANCIS CLASSICO | 2 | UN | 1,6 | 3,20
49299936 | SAB.FRANCIS CLASSICO | 1 | UN | 1,6 | 1,60
52390900 | CREME FERRERO AVELA | 1 | UN | 26,9 | 26,90
23286105 | OVO PVC GDE VERMELHO | 1 | UN | 9,99 | 9,99
Valor total R$ | 270,78
Valor descontos R$ | 2,44
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:52